package CPAN::Packager::DependencyFilter::RPM;
use Mouse;
with 'CPAN::Packager::DependencyFilter::Role';

__PACKAGE__->meta->make_immutable;
1;
